# Go开发

## 1、概述
  通过通用集成开发环境进行Go项目开发。

## 2、环境准备
- 请先在系统中自行安装Go运行环境。
- Kylin Go插件安装   
  - 启动通用集成开发环境
  - 点击活动栏中的插件图标，调出插件视图。   
  - 点击插件视图中的插件筛选器图标，选择Kylin-IDE(KylinCode)插件分类->Go语言支持
  ![2-1](./resources/go/go-install.png "插件安装")
  - 通过以上步骤找到Go语言相关插件Kylin Go，点击插件右下角的安装图标进行安装操作
  - 安装成功后，重新加载窗口

# 快速开始

## 1、 创建Go项目
  - 在终端创建文件夹myProjectGo
  - 启动通用集成开发环境，点击文件->打开文件夹，选择myProjectGo
  - 点击新建文件图标，创建Go文件main.go  
  ![2-2](./resources/go/go-createfile.png "创建项目")

## 2、 编辑
  - 在新建的main.go文件中输入Go代码
    ```Go
    package main

    import "fmt"

    func main() {
    	msg := "hello world"
    	fmt.Println(msg)
    }

    ```
### 2.1、 自动补全、代码着色
    
   ![2-1](./resources/go/go-autocomplete.gif "代码补全")

### 2.2、 代码导航
  在编辑区的右键菜单中可以看到支持的代码导航,比如转到定义、转到实现、转到引用等   
  ![2-2](./resources/go/go-jump.gif "代码跳转")

## 3、 运行
  需要创建运行配置文件tasks.json，tasks.json文件被存储在.vscode文件夹内。创建方法如下：
  - 点击菜单中的终端->配置任务->使用模板创建tasks.json文件->others   
  - tasks.json文件创建成功    
    创建的tasks.json默认内容如下：
    ```json
    {
    // See https://go.microsoft.com/fwlink/?LinkId=733558
    // for the documentation about the tasks.json format
    "version": "2.0.0",
    "tasks": [
        {
            "label": "echo",
            "type": "shell",
            "command": "echo Hello"
        }
      ]
    }
    ```
  - 修改tasks.json文件，修改后内容如下：
    ```json
    {
    // See https://go.microsoft.com/fwlink/?LinkId=733558
    // for the documentation about the tasks.json format
    "version": "2.0.0",
    "tasks": [
        {
            "label": "run", //运行任务的名称
            "type": "shell",
            "command": "go",
            "args": ["run", "main.go"]
        }
      ]
    }
    ```
  - 点击菜单中的终端->运行任务->run->继续而不扫描任务输出,运行任务
  - 在终端输出运行结果    
   ![3-1](./resources/go/go-run.gif)

## 4、 调试
### 4.1、 一键调试
  对于一个简单的Go文件的调试，不需要进行调试配置，支持一键调试。    
  - 在main.go文件左侧点击鼠标左键添加断点
  - 键盘按键F5   
  - 如果出现`go: cannot find main module; see 'go help modules'`错误，请在myProjectGo目录下创建go.mod文件，写入`module main`
    ![4-1](./resources/go/go-mod.png)   
  - 调试结果  
    ![4-2](./resources/go/go-debug.png "一键调试")

### 4.2、 自定义调试
  对于复杂的项目，需要创建调试配置文件launch.json，launch.json文件被存储在.vscode文件夹内。创建方法如下：
  - 点击菜单中的运行->添加配置,选择“Go:Launch Package”    
  ![4-2](./resources/go/go-debug-config.png)   
  - launch.json文件创建成功    
    创建的launch.json默认内容如下：
    ```json
    {
        // 使用 IntelliSense 了解相关属性。 
        // 悬停以查看现有属性的描述。
        // 欲了解更多信息，请访问: https://go.microsoft.com/fwlink/?linkid=830387
        "version": "0.2.0",
        "configurations": [
            {
                "name": "Launch Package",
                "type": "go",
                "request": "launch",
                "mode": "auto",
                "program": "${fileDirname}"
            }
        ]
    }
    ```
    该launch.json文件配置可以调试myProjectGo,其他项目用户需要根据具体情况修改launch.json文件,例如修改调试文件：
    ```json
    "program": "${workspaceFolder}/main.go",//修改调试文件
    ```
  - 在main.go文件左侧点击鼠标左键添加断点
  - 点击左侧活动栏中的调试按钮，切换到调试视图   
  - 点击“Launch Package”启动调试


