# Java开发使用说明

## 1、概述

  本文档介绍用户如何通过IDE软件进行Java项目开发。

  
  包括java编辑、编译、运行、调试等过程。

## 2、环境准备

- 系统安装Java开发工具包（JDK 11+）。如果您还没有安装JDK，请从官方源安装，或者自行下载安装。

    ``` shell
    sudo apt install openjdk-11-jdk
    ```
- 在IDE软件中安装Java扩展。
  - 启动IDE软件
  - 点击活动栏中的插件图标，调出插件视图。
  - 点击插件视图中的插件筛选器图标，选择Kylin-IDE(KylinCode)插件分类->Java语言支持

  ![图1](./resources/java/extension-list.png "Java语言支持插件查看")
  - 通过以上步骤找到java语言相关插件 KylinIDETeam.vscode-java-pack
  - KylinIDETeam.vscode-java-pack（Kylin Extension Pack for Java）插件安装：

    点击插件右下角的安装图标进行安装操作。

    会自动安装java相关支持插件，包括：
  
    - kylinideteam.java （Kylin Language Support for Java）
    - kylinideteam.vscode-maven (Kylin Maven for Java)
    - kylinideteam.vscode-java-debug (Kylin Debugger for Java)
    - kylinideteam.vscode-java-test (Kylin Test Runner for Java)
    - kylinideteam.vscode-java-dependency (Kylin Project Manager for Java)
    - kylinideteam.vscode-gradle (Kylin Gradle for Java)

  - 安装成功后，重新加载窗口

## 3、快速开始

### 3.1、创建Java项目

- 参考“项目管理”下的“3.2、创建简单Java项目”：[创建Java项目](项目管理.md#3.2、创建简单Java项目)

### 3.2、配置Java项目

- 完成创建后，打开testJava项目
- 参考“项目管理”下的“4.2、配置Java项目”:[配置Java项目](项目管理.md#4.2、配置Java项目)

### 3.3、编辑

- 打开src/main.java文件

    ```java
    public class main {
        public static void main(String[] args) throws Exception {
            System.out.println("Hello, World!");
        }
    }

    ```

#### 3.3.1、代码提示

  IDE软件提供了代码补全、代码着色、参数信息等。如图所示

   ![图代码补全](./resources/java/intellisense.png)

#### 3.3.2、代码导航

  在编辑区的右键菜单中可以看到支持的代码导航,比如转到定义、转到实现、转到引用等

  ![图代码导航](./resources/java/right-menu.png)

### 3.4、编译、运行

在项目的.vscode目录下有运行配置文件tasks.json，如果没有需要创建。
  
创建方法如下：

- 点击菜单中的终端->配置任务->使用模板创建tasks.json文件->others
- tasks.json文件创建成功

    创建的tasks.json默认内容如下：

    ```json
    {
    // See https://go.microsoft.com/fwlink/?LinkId=733558
    // for the documentation about the tasks.json format
    "version": "2.0.0",
    "tasks": [
        {
            "label": "echo",
            "type": "shell",
            "command": "echo Hello"
        }
      ]
    }
    ```

- 修改tasks.json文件，修改后内容如下：

    ```json
    
    {
        "label": "build", 
        "type": "shell", 
        "options": {
            "cwd": "${workspaceFolder}"
        }, 
        "command": "javac", 
        "args": [
            "src/main.java",
            "-sourcepath",
            "src",
            "-classpath",
            "${config:java.project.referencedLibraries}",
            "-d", 
            "${config:java.project.outputPath}"
        ]
    }, 
    {
        "label": "run", 
        "type": "shell", 
        "options": {
            "cwd": "${workspaceFolder}"
        }, 
        "command": "java", 
        "args": [
            "-cp", 
            "${config:java.project.outputPath}", 
            "main"
        ], 
        "dependsOn": [
            "javac"
        ]
    }
    ```

#### 3.4.1、编译

- 点击“项目操作区”的“编译”按钮；或点击菜单中的终端->运行任务->build->继续而不扫描任务输出,运行build任务
- 在终端输出运行结果

   ![编译结果](./resources/java/build.png "编译结果")

#### 3.4.2、运行

- 点击“项目操作区”的“运行”按钮；或点击菜单中的终端->运行任务->run->继续而不扫描任务输出,运行run任务

- 在终端输出运行结果

   ![运行结果](./resources/java/run.png "运行结果")

### 4、调试

#### 4.1、一键调试

  对于一个简单的Java程序文件的调试，不需要进行配置，支持一键调试。

- test.java文件左侧点击鼠标左键添加断点
- 如图，点击左侧活动栏中的调试按钮，切换到调试视图

    ![图2](./resources/java/debug-sample.png "调试视图")
- 点击运行和调试按钮启动调试

    ![图3](./resources/java/debug-sample2.png "启动调试")
- 如图此种简单调试，没有配置

#### 4.2、自定义调试

打开一个Java项目（本文以Calculator计算器例程）为例。
在项目的.vscode目录下有运行配置文件tasks.json，如果没有需要创建。
创建方法如下：

- 点击菜单中的运行->添加配置

  ![图4](./resources/java/add-launch.png)

- launch.json文件创建成功

    创建的launch.json默认内容如下：

    ```json
    {
        // 使用 IntelliSense 了解相关属性。 
        // 悬停以查看现有属性的描述。
        // 欲了解更多信息，请访问: https://go.microsoft.com/fwlink/?linkid=830387
        "version": "0.2.0",
        "configurations": [
            {
                "type": "java",
                "name": "Launch Current File",
                "request": "launch",
                "mainClass": "${file}"
            },
            {
                "type": "java",
                "name": "Launch Calculator",
                "request": "launch",
                "mainClass": "Calculator",
                "projectName": "calculator_cb38a00"
            }
        ]
    }
    ```

    将launch.json修改为：

    ```json
    {
        "version": "0.2.0",
        "configurations": [
            {
                "type": "java",
                "name": "Launch Current File",
                "request": "launch",
                "mainClass": "${file}",
                "args": ""
            },
            {
                "type": "java",
                "name": "Launch Calculator",
                "request": "launch",
                "mainClass": "${file}",
                "projectName": "${workspaceFolderBasename}"
            }
        ]
    }
    ```

    该launch.json文件配置可以调试 Calculator,其他项目用户需要根据具体情况修改launch.json文件

- 在Calculator.java文件左侧第20行点击鼠标左键添加断点；
- 在Calculator.java文件左侧第40行点击鼠标左键添加断点；

    ![调试](./resources/java/debug-project.png "调试视图")

- 点击“项目操作区”的“调试”按钮，切换到调试视图
- 点击Launch main启动调试
  - 第一个断点，停在Calculator.java 20行处，如图,可以查看当前参数、堆栈信息、断点信息、变量等。

    ![图2](./resources/java/debug-project-step-1.png "调试中断")

  - 点击继续，如图：

    ![图2](./resources/java/debug-operation.png "调试第一步")

  - 程序运行成功，显示应用视图：

    ![图2](./resources/java/debug-project-step-2.png "运行")

  - 点击1，点击+号，程序中断，如图：

    ![图2](./resources/java/debug-project-step-3.png "调试中断")

  - 点击2，点击=号，得到结果3.0，如图：

    ![图2](./resources/java/debug-project-step-4.png "调试中断")

  以上就是Java项目的调试过程。
