"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Localize = void 0;
/*
 * @Author: Kylinos
 * @Date: 2022-02-21 11:44:01
 * @LastEditors: Kylinos
 * @LastEditTime: 2022-02-25 12:44:34
 * @FilePath: /vscode-package-builder/src/localize.ts
 * @Description:
 * vscode多语言支持
 * Copyright (c) 2022 by Kylinos, All Rights Reserved.
 */
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const vscode_1 = require("vscode");
class Localize {
    constructor() {
        this.bundle = this.resolveLanguagePack();
    }
    localize(key, ...args) {
        const message = this.bundle[key] || key;
        return this.format(message, args);
    }
    init() {
        try {
            this.options = Object.assign(Object.assign({}, this.options), JSON.parse(process.env.VSCODE_NLS_CONFIG || '{}'));
        }
        catch (err) {
            throw err;
        }
    }
    format(message, args = []) {
        return args.length
            ? message.replace(/\{(\d+)\}/g, (match, rest) => args[rest[0]] || match)
            : message;
    }
    /**
     * @description: 加载多语言配置文件，配置文件命名规则为：package.nls{0}.json ,{0}为对应的语言代码,如en,zh_cn...
     * @param {*}
     * @return {ILanguagePack} 多语言字典
     */
    resolveLanguagePack() {
        var _a;
        this.init();
        const languageFormat = 'package.nls{0}.json';
        const defaultLanguage = languageFormat.replace('{0}', '');
        let rootPath = (_a = vscode_1.extensions === null || vscode_1.extensions === void 0 ? void 0 : vscode_1.extensions.getExtension('KylinIDETeam.kylin-ide-user-help')) === null || _a === void 0 ? void 0 : _a.extensionPath;
        if (rootPath === undefined) {
            rootPath = vscode_1.extensions.getExtension.name;
        }
        const resolvedLanguage = this.recurseCandidates(rootPath, languageFormat, this.options.locale);
        const languageFilePath = (0, path_1.resolve)(rootPath, resolvedLanguage);
        try {
            const defaultLanguageBundle = JSON.parse(resolvedLanguage !== defaultLanguage
                ? (0, fs_extra_1.readFileSync)((0, path_1.resolve)(rootPath, defaultLanguage), 'utf-8')
                : '{}');
            const resolvedLanguageBundle = JSON.parse((0, fs_extra_1.readFileSync)(languageFilePath, 'utf-8'));
            return Object.assign(Object.assign({}, defaultLanguageBundle), resolvedLanguageBundle);
        }
        catch (err) {
            throw err;
        }
    }
    recurseCandidates(rootPath, format, candidate) {
        const filename = format.replace('{0}', `.${candidate}`);
        const filepath = (0, path_1.resolve)(rootPath, filename);
        if ((0, fs_extra_1.existsSync)(filepath)) {
            return filename;
        }
        if (candidate.split('-')[0] !== candidate) {
            return this.recurseCandidates(rootPath, format, candidate.split('-')[0]);
        }
        return format.replace('{0}', '');
    }
}
exports.Localize = Localize;
exports.default = Localize.prototype.localize.bind(new Localize());
//# sourceMappingURL=localize.js.map