"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandAbstract = void 0;
/*
 * @Author: Kylinos
 * @Date: 2022-02-21 11:44:01
 * @LastEditors: Kylinos
 * @LastEditTime: 2022-02-25 18:06:27
 * @FilePath: /vscode-package-builder/src/manager/commandBase.ts
 * @Description:
 * 将插件中所有提供的command进行对象化抽象
 * Copyright (c) 2022 by Kylinos, All Rights Reserved.
 */
const vscode = require("vscode");
const os = require("os");
/**
 * 将命令抽象，构造函数设置command，子类需要实现process函数完成具体逻辑
 */
class CommandAbstract {
    /**
     * @description: command构造函数
     * @param {string} command
     * @param {vscode} context
     * @param {string} title
     * @param {string} category
     * @return {*}
     */
    constructor(command, context, title, category) {
        //command唯一标识
        this.command = '';
        //工作区目录，默认为homedir
        this.workRootDir = os.homedir();
        //command标题
        this.title = '';
        //command分组
        this.category = '';
        this.category = category;
        this.title = title;
        this.command = command;
        this.context = context;
    }
    /**
     * @description: 将当前command注册到vscode中
     * @param {*}
     * @return {*}
     */
    registe() {
        let createWorkspace = vscode.commands.registerCommand(this.command, this.process, this);
        this.context.subscriptions.push(createWorkspace);
    }
}
exports.CommandAbstract = CommandAbstract;
//# sourceMappingURL=commandBase.js.map