"use strict";
/*
 * @Author: Kylinos
 * @Date: 2022-02-21 11:44:01
 * @LastEditors: Kylinos
 * @LastEditTime: 2022-02-25 16:34:07
 * @FilePath: /vscode-package-builder/src/manager/commonCommand.ts
 * @Description:
 * 定义一些公共的command
 * Copyright (c) 2022 by Kylinos, All Rights Reserved.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TreeViewblankClick = exports.TreeViewItemClick = void 0;
const commandBase_1 = require("./commandBase");
const vscode = require("vscode");
const path = require("path");
const localize_1 = require("../localize");
const fs = require("fs");
/**
 * 实现Treeview中点击某个元素默认执行的命令
 */
class TreeViewItemClick extends commandBase_1.CommandAbstract {
    constructor(context) {
        super('tree.item.click', context);
    }
    /**
     * @description: 当点击的元素为文本文档是，自动打开该文件
     * @param {MyTreeItem} item Treeview中被点击的节点
     * @return {*}
     */
    process(item, args) {
        if (item.contextValue.startsWith('file')) {
            let filePath = path.join(item.parentPath, item.labelrelease);
            if (!fs.existsSync(filePath)) {
                vscode.window.showErrorMessage((0, localize_1.default)('extension.error.filenotexist'), filePath);
                return;
            }
            vscode.commands.executeCommand('markdown.showPreview', vscode.Uri.file(filePath), null, { locked: true });
        }
    }
}
exports.TreeViewItemClick = TreeViewItemClick;
/**
 * 实现Treeview中点击搜索按钮执行命令
 *
 */
class TreeViewblankClick extends commandBase_1.CommandAbstract {
    constructor(context) {
        super('tree.item.search', context);
    }
    /**
     * @description: 当点击的元素为文本文档是，自动打开该文件
     * @param {MyTreeItem} item Treeview中被点击的节点
     * @return {*}
     */
    process(item, args) {
        let regexStr = '';
        let searchpath = path.join(this.context.extensionPath, 'get_markdown');
        // vscode.commands.executeCommand('search.action.openNewEditor', {
        //     query: regexStr,
        //     triggerSearch: true,
        //     filesToInclude: searchpath
        // } as IFindInFilesArgs);
        vscode.commands.executeCommand('markdown.showPreview');
        // vscode.commands.executeCommand('workbench.action.search.toggleQueryDetails');
    }
}
exports.TreeViewblankClick = TreeViewblankClick;
//# sourceMappingURL=commonCommand.js.map