"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MyTreeDataManager = exports.MyTreeItem = void 0;
const vscode = require("vscode");
const fs = require("fs");
const path = require("path");
const vscode_1 = require("vscode");
/**
 * treeview中每个节点元素对象，继承自TreeItem
 */
class MyTreeItem extends vscode_1.TreeItem {
    constructor(
    //当前节点显示内容
    label, labelrelease, collapsibleState, 
    //当前节点父节点
    parentPath, 
    //treeviewId
    viewId) {
        super(label, collapsibleState);
        this.label = label;
        this.labelrelease = labelrelease;
        this.collapsibleState = collapsibleState;
        this.parentPath = parentPath;
        this.viewId = viewId;
        /**
         * 配置每个元素点击是触发的command , arguments为传递的参数
         */
        this.command = {
            title: 'this.label',
            command: 'tree.item.click',
            arguments: [
                this
            ]
        };
        this.contextValue = '';
        //当前目录是否包含control文件
        this.containDebControl = false;
        this.pathFrom = vscode.Uri.file("/home");
    }
}
exports.MyTreeItem = MyTreeItem;
/**
 * Treeview实现类，继承自vscode接口TreeDataProvider
 */
class MyTreeData {
    /**
     * @description: 构造函数
     * @param {string} rootPath 根目录路径
     * @param {string} viewId treeviewid
     * @return {*}
     */
    constructor(rootPath, viewId) {
        this.rootPath = rootPath;
        this.viewId = viewId;
        this._onDidChangeTreeData = new vscode_1.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
        this.setRoot(rootPath);
        this.viewId = viewId;
    }
    /**
     * @description: 设置工作区跟目录
     * @param {string} root
     * @return {*}
     */
    setRoot(root) {
        let oldRoot = this.rootPath;
        if (this.rootPath !== root) {
            this.rootPath = root;
            this.refresh();
        }
        //如果为空，关闭treeview导航菜单按钮
        if (this.rootPath === '') {
            vscode.commands.executeCommand('setContext', this.viewId + '.opentree', false);
        }
        else {
            vscode.commands.executeCommand('setContext', this.viewId + '.opentree', true);
        }
    }
    getRoot() {
        let rp = this.rootPath;
        return rp;
    }
    getTreeItem(element) {
        return element;
    }
    /**
     * @description: 获取子节点
     * @param {MyTreeItem} element
     * @return {*}
     */
    getChildren(element) {
        if (!this.rootPath) {
            return Promise.resolve([]);
        }
        if (element === undefined) {
            return Promise.resolve(this.searchFiles(this.rootPath));
        }
        else {
            // return Promise.resolve(this.searchFiles(path.join(element.parentPath, lablenew)));
            return Promise.resolve(this.searchFiles(path.join(element.parentPath, element.label)));
        }
    }
    refresh() {
        this._onDidChangeTreeData.fire();
    }
    /**
     * @description: 便利目录下文件，并生成MyTreeItem实例
     * @param {string} parentPath 父目录
     * @return {*}
     */
    searchFiles(parentPath) {
        let treeDir = [];
        // const parentPath1 = path.join(parentPath, 'files');
        if (this.pathExists(parentPath)) {
            let fsReadDir = fs.readdirSync(parentPath, 'utf-8');
            let listnew = ['简介.md', '支持的平台.md', 'IDE基础平台.md', '推荐插件列表.md', '如何检索和安装插件.md', '插件依赖管理.md', '离线插件管理.md', '项目管理.md', '版本管理工具.md', '远程开发.md', 'C-C++开发.md', 'Java开发.md', 'Python开发.md', 'Go开发.md', 'JavaScript开发.md', '死锁检测.md', '打包.md', '历史调试.md', '问题反馈.md'];
            fsReadDir = fsReadDir.sort((a, b) => {
                return listnew.indexOf(a) - listnew.indexOf(b);
            });
            fsReadDir.forEach(fileName => {
                let filePath = path.join(parentPath, fileName); //Use absolute path
                let filename3 = '';
                // if(fileName==doid){
                //     let myItem: MyTreeItem = new MyTreeItem(fileName, fileName, TreeItemCollapsibleState.None, parentPath, this.viewId);
                //     myItem.contextValue = 'folder';
                //     treeDir.push(myItem);
                // }
                if (fileName.indexOf('.md') != -1) {
                    let l = fileName.indexOf('.md');
                    let filename3 = fileName.substring(0, l);
                    let myItem = new MyTreeItem(filename3, fileName, vscode_1.TreeItemCollapsibleState.None, parentPath, this.viewId);
                    myItem.contextValue = 'file';
                    treeDir.push(myItem);
                }
            });
        }
        return treeDir;
    }
    pathExists(filePath) {
        try {
            fs.accessSync(filePath);
        }
        catch (err) {
            return false;
        }
        return true;
    }
}
/**
 * Treeview管理类,单例模式实现
 */
class MyTreeDataManager {
    constructor() {
        this.__myTreeDatas = new Map();
    }
    /**
     * @description: 获取MyTreeDataManager实例
     * @param {*}
     * @return {*}
     */
    static getInstance() {
        if (this._instance === undefined) {
            this._instance = new MyTreeDataManager();
        }
        return this._instance;
    }
    /**
     * @description: 获取treeview
     * @param {string} treeKey
     * @return {*}
     */
    getTreeData(treeKey) {
        let mytree = this.__myTreeDatas.get(treeKey);
        if (mytree === undefined) {
            mytree = new MyTreeData('', treeKey);
            this.__myTreeDatas.set(treeKey, mytree);
            vscode.window.createTreeView(treeKey, {
                treeDataProvider: mytree,
            });
        }
        return mytree;
    }
}
exports.MyTreeDataManager = MyTreeDataManager;
//# sourceMappingURL=tvProvider.js.map